% short description of function
%
% Diese Funktion berechnet die Temperatur der Gewchshaushlle
% (Innenseite), TEMG, [C]
%
% Syntax:  [ou1, out2] = funname(in1, in2, in3)
%
% Input parameter:
%    TEMI      - Temperatur innen
%    TEMA      - Temperatur aussen
%    IGLOB     - Globalstrahlung
%    Time      - Zeit
%
% Output parameter:
%    TEMG      - Temperatur der Gewaechshaushuelle
%
% See also: simgrhs3

% Author:   Hartmut Pohlheim
% History:  11.03.97    file created


function TEMG = calctemg(TEMI, TEMA, IGLOB, Time);

   % TEMI = X(2);
   % TEMA = KLIMA(3)
   % IGLOB = KLIMA(6)

   % hollaendische Gleichung (Monate 1-4 und 10-12
   % Calculation of greenhouse temperature, TEMG
   % hollaendische Gleichung (Monate 1-4 und 10-12)
   if any([Time <= ((31+28+31+30)*24*3600), Time >= ((31+28+31+30+31+30+31+31+30)*24*3600)]),
      TEMG = TEMI - 2/3 * (TEMI - TEMA);
   % Dr.Heissners Gleichung, speziell fuer Sommer (Monate 5-9), mit IGLOB
   else
      TEMG = -2.71 + 0.00811 .* IGLOB + 0.795 .* TEMI + 0.289 .* TEMA;
   end   

   % IxColdTemg = find([Time <= ((31+28+31+30)*24*3600) | Time >= ((31+28+31+30+31+30+31+31+30)*24*3600)])
   % IxSummerTemg  = 1:length(Time); IxSummerTemg(IxColdTemg) = []


% End of function
