% COMPute diverse things for the GReenHouSe system
%
% This function computes diverse small things used inside
% the greenhouse system at different places.
%
% Syntax:  [OP1, OP2, OP3, OP4, OP5] = compgrhs(What, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10)
%
% Input parameter:
%    What      - String containing the thing to do
%    P1-P10    - Input parameters
%
% Output parameter:
%    OP1-OP5   - Output parameters
%
% See also: initgrh3, objgrh3, scrgrh4

% Author:   Hartmut Pohlheim
% History:  11.03.97    file created


function [OP1, OP2, OP3, OP4, OP5] = compgrhs(What, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10)
 
% Check input parameters
   if nargin < 1, What = []; end 
   if isempty(What), error('Parameter WHAT undefined! Do you know what you want?'); end

% Create vector with hours per month
   if strcmp(lower(What), 'hours_per_month'),
      HourPerMonth = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31] * 24;
      OP1 = HourPerMonth;

% Convert time to month
   elseif strcmp(lower(What), 'convert_time2month'),
      % Get input parameters
      Time = P1(:);
      HourPerMonthMat = compgrhs('hours_per_month');
      Hour2MonthMat = cumsum(HourPerMonthMat);
      
      % Find the matching month and day of month (24:00 is 0:00 of next day)
      % TMonth = length(Hour2MonthMat) +1 - sum((Time(1)+1)/3600 <= Hour2MonthMat)
      TMat = repmat(Time,[1,length(Hour2MonthMat)]);
      HMat = repmat(Hour2MonthMat,[length(Time),1]);
      TMonth = (1 + length(Hour2MonthMat)) - sum(((TMat+1)/3600 <= HMat)')';
      
      HMat2 = [0 Hour2MonthMat];
      TDayofMonth = (Time - (HMat2(TMonth)*3600)');
      TDayofMonth = 1 + fix(fix(TDayofMonth)/3600/24);
      OP1 = [TMonth TDayofMonth];
      if nargout > 1,
         for iout = 1:size(OP1, 1),
            OP2(iout,:) = sprintf('%2d.%02d.', TDayofMonth(iout,:), TMonth(iout,:) );
         end
      end

% Convert time (in seconds) to  [day of year, hour, minute, second]
% remember: 24:00 is 0:00 of next day
   elseif strcmp(lower(What), 'convert_time2dayhour'),
      % Get input parameters
      Time = P1(:);
      % Compute values
      TDayofYear = 1 + fix(fix((Time)/3600)/24);
      THour = fix(rem(Time, 3600*24)/3600);
      TMinute = fix(rem(Time, 3600)/3600*60);
      TSecond = rem(Time, 60);
      OP1 = [TDayofYear THour TMinute TSecond];
      if nargout > 1,
         for iout = 1:size(OP1, 1),
            OP2(iout,:) = sprintf('%3d. %2d:%02d:%02d', OP1(iout,:));
         end
      end
      
% Look up data for Klima and Plant
   elseif strcmp(lower(What), 'lookup_klimaplant'),
      % Get input parameters
      TSTART = P1; TEND = P2; % Both times in seconds
      % Create vector with times every hour
      TimeHalfHour = [TSTART:(30*60):TEND]';
      if TimeHalfHour(length(TimeHalfHour)) ~= TEND, TimeHalfHour = [TimeHalfHour; TEND]; end
      % Look up data
      [KLIMA, PLANT] = klidata4(TimeHalfHour);
      % Create matrix
      DataKlimaPlant = [TimeHalfHour, KLIMA, PLANT];
      OP1 = DataKlimaPlant;
      
% If unknown option, issue an error message
   else
      disp(sprintf('compgrhs.m: Unknown option for action! (%s)', What));
   end


% End of function
