% Ermittlung der Daten fuer Klima und Plant 3
%
% Funktion zur Darstellung der Daten: KLIMA, PLANT
%
% Syntax:  [Klima] = klidata4(Time)
%
% Input parameter:
%    Time      - Vektor containing the time values in seconds
%
% Output parameter:
%    Klima     - Matrix containg the Klima data corresponding
%                   with the time values in Time
%                   every row corresponds to one time value
%
% See also: simgrhs3, objgrhs3, scrgrhs4

% Author:   Hartmut Pohlheim
% History:  13.03.97    file created


function [KLIMA, PLANT] = klidata4(Time);

% Parameters of the climate
   % TEMB, Temperatur der Bodenoberflche, C
   % TEMG, Temperatur der Gewchshaushlle (Innenseite), C
   % TEMA, Auentemperatur, C
   % FA, Auenluftfeuchte, % r.F.
   % CA, Auen-CO2-Konzentration, ppm
   % IGLOB, Globalstrahlung, W/m
   % U, Windgeschwindigkeit, m/s

% Load data from one file
   FileKlimaData = 'weat95_1.dat';
   [Header, KlimaDataAll] = hdrload(FileKlimaData);
   % Extract needed data
   KlimaTimeData = KlimaDataAll(:, 5:size(KlimaDataAll,2));

   % Check Time boundaries
   if min(Time) < KlimaTimeData(1, 1),
      error('Minimal time (of simulation) is smaller than minimal time of known data values!');
   elseif max(Time) > KlimaTimeData(size(KlimaTimeData,1), 1),
      error('Maximal time (of simulation) is greater than maximal time of known data values!');
   end

   % Lookup climate data according time
   KLIMA = table1(KlimaTimeData, Time);
  
% Parameters of the plants
   % Blattflchenindex, A, m/m (3 Pflanzen pro m)
   % Transpiration pro Blattflche unter Standardbedingungen, V0, g H2O/(dm.h)
   % CO2-Gaswechsel pro Blattflche unter Standardbedingungen, P0, g CO2/(dm.h)
   %          A      P0      V0 
   PLDat = [0.5   0.015    1.0;  % 1.1.
            0.5   0.015    1.0;  % january
            0.5   0.015    1.0;  % february
            0.8   0.015    1.0;  % march
            1.5   0.015    1.0;  % april
            2.0   0.015    1.0;  % may
            2.0   0.015    1.0;  % june
            2.0   0.015    1.0;  % july
            2.0   0.015    1.0;  % august
            2.0   0.015    1.0;  % september
            2.0   0.015    1.0;  % october
            1.0   0.015    1.0;  % november
            0.5   0.015    1.0   % december
           ];

   PlantTime = Time ./ 3600;
   HoursPerMonthMat = [0, cumsum(compgrhs('hours_per_month'))]';

   % Lookup data for Plant
   PLANT = table1([HoursPerMonthMat, PLDat], PlantTime);


% End of function
