% PLOTing of results of GReenHouSe simulation 3
%
% This function plots some of the results during computation
% of the greenhouse system.
%
% Syntax:  plotgrh4(OBJ_F, chrom, gen, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10)
%
% Input parameters:
%    OBJ_F     - Vector containing the (name of the) objective function
%                if empty, chrom contains the name of a data files with results
%    chrom     - (row) Vector containing the individual for simulation and
%                   displaying the results
%    gen       - Scalar containing the number of the current generation
%    P1-P10    - additional parameters, see OBJ_F (for instance objgrh3)
%
% Output parameter:
%    no output parameter
%
% See also: objgrhs3, objgrhs4

% Author:   Hartmut Pohlheim
% History:  13.03.97    file created


function plotgrh4(OBJ_F, chrom, gen, varargin);

% Look for input parameters
   if nargin < 3, gen = []; end
   if isempty(gen), gen = 1; end

% Differentiate between ploting results from file and ploting states from simulation
% Both use the same plot routines, however, the way of receiving data is different
   if isempty(OBJ_F),
      [ResHead, ResData] = hdrload(chrom);
      t = ResData(:,4);
      x = ResData(:,5:9);
      ControlTable = ResData(:,12:14);
      if size(ResData, 2) > 14, KlimaPlant = ResData(:,15:24);
      else KlimaPlant = []; DataKlimaPlant = []; end
   else
      % Build string of objective function
      % genevalstr = ['[objval, t, x] = ' OBJ_F '(x'];
      % if ~any(OBJ_F < 48), for i = 1:nargin-3,  genevalstr = [genevalstr, ',P', int2str(i)]; end, genevalstr = [genevalstr, ');']; end

      % Compute states of individual x by calling objective function
      x = chrom(1,:);
      [objval, t, x] = feval(OBJ_F, x, varargin{:})
      % eval(genevalstr);

      % Get size of individual and states
      [Nind, Nvar] = size(chrom);
      [Nstep, Nstate] = size(x);

      NCONTR = 3;
      ControlSteps = Nvar/NCONTR;
      ControlTable = reshape(chrom, ControlSteps, NCONTR);
      timevec = linspace(t(1), t(length(t)), ControlSteps)';
      ControlTable = table1([timevec, ControlTable], t);

      if nargin < 7, DataKlimaPlant = []; else DataKlimaPlant = varargin{4}; end
      KlimaPlant = [];

   end

% look for figure, set Name, set standard properties
   FigName = 'gatbxfigresultplot_plotgrh3';
   figplotgrhs = findobj('UserData', FigName);
   if isempty(figplotgrhs),
      figplotgrhs = figure('UserData', FigName);
   end
   if isempty(OBJ_F),
      set(figplotgrhs,'Name', sprintf('Simulation results of %s', chrom));
   else
      set(figplotgrhs,'Name', sprintf('Simulation results of %s in gen %g', OBJ_F(1:min(8, size(OBJ_F, 2))), gen));
   end
   set(figplotgrhs,'NumberTitle','Off');
   % set(figplotgrhs, 'PaperPosition', [0.5 2.5 12 9]);     % use for subplot(2,2,*)
   set(figplotgrhs, 'PaperPosition', [0.5 2.5 8.5 11.2]);     % use for subplot(4,1,*)
   plotstd(figplotgrhs);
   figure(figplotgrhs);
   vers = version;
   if vers(1) >= '5', set(figplotgrhs, 'DefaultTextInterpreter', 'none'); end

   plotkind = 1;
   if plotkind == 1,

      % Some interactive plot stuff
      iinput = 1;
      while iinput < 3,
         if iinput == 1,
            IxPlot = [1:length(t)];
            if length(gen) > 1,
               gen(1) = floor(t(1)/3600)/24; gen(2) = ceil(t(length(t))/3600)/24;
               IxPlot = [1:length(t)];
            else iinput = 2; end
         else
            WhatTask = [];
            while ~(WhatTask == 'p'),  
               DataString = sprintf('stArt (%d of %d), End (%d of %d), Plot, eXit ', ...
                                    gen(1), floor(t(1)/3600)/24, gen(2), ceil(t(length(t))/3600)/24);
               WhatTask = input(sprintf('%s\nWhat to do?: ', DataString), 's');
   
               % Define new PlotStart
               if WhatTask == 'a',
                  gen(1) = input(sprintf('New PlotStart (%d): ', gen(1)));
               % Define new PlotEnd
               elseif WhatTask == 'e',
                  gen(2) = input(sprintf('New PlotEnd (%d): ', gen(2)));
               elseif WhatTask == 'p', iinput = 1;
                  IxStartTime = max(1, sum(t <= (gen(1)*24*3600)));
                  IxEndTime = sum(t <= (gen(2)*24*3600)); 
                  IxPlot = [IxStartTime:IxEndTime];
               % If nothing of the above, then exit function
               else return; end
            end
         end

         % Convert time from seconds to days
         th = t(IxPlot)./3600./24;
         
         % Compute limit of x-axis, round to next full hour
         XLimTime = [floor(th(1)*24)/24, ceil(th(length(th))*24)/24];
      
         language = 'german';
         % language = 'english';
         [TSD, TSDayHour] = compgrhs('convert_time2dayhour', t(IxPlot(1)));
         [TSM, TSMonth] = compgrhs('convert_time2month', t(IxPlot(1)));
         [TED, TEDayHour] = compgrhs('convert_time2dayhour', t(IxPlot(length(IxPlot))));
         [TEM, TEMonth] = compgrhs('convert_time2month', t(IxPlot(length(IxPlot))));
         DateAll = sprintf(': %s %2d:%02d - %s %2d:%02d', TSMonth, TSD(2), TSD(3), TEMonth, TED(2), TED(3));
         DaysAll = TED(1) - TSD(1);
         if strcmp(lower(language), 'german'),
            Title1 = 'Gewchshausklima';
            Title2 = 'Biomasse und Gewinn';
            Title3 = 'Steuerung';
            Title4 = ['Wetter' DateAll];
            Xlabelall = 'Zeit [d]';
            % Ylabel1 = 'TEMI (___), DDI (---), CI (...)';
            % Ylabel2 = 'Biomasse (---), Gewinn (___)';
            % Ylabel3 = 'Heizung (---), Lftung (___), CO2 (...)';
            Ylabel1 = 'TEMI, DDI, CI';
            Ylabel2 = 'Biomasse, Gewinn';
            Ylabel3 = 'Heizung, Lftung, CO2';
            Ylabel4 = 'Klimadaten';
            Legend1 = ['TEMI  '; 'DDI   '; 'CI/100'];
            Legend2 = ['Biomasse/100'; 'Gewinn      '];
            Legend3 = ['Heizung'; 'Lftung'; 'CO2*10 '];
            Legend4 = ['TEMB    ';'TEMG    ';'TEMA    ';'FA      ';'CA/10   ';'IGLOB/10';'U*10    '];
            Legend5 = ['TEMB    ';'TEMG    ';'TEMA    ';'FA      ';'IGLOB/10'];
         else
            Title1 = 'greenhouse climate';
            Title2 = 'biomass and profit';
            Title3 = 'control equipment';
            Title4 = ['climate' DateAll];
            Xlabelall = 'time [d]';
            % Ylabel1 = 'TEMI (___), DDI (---), CI (...)';
            % Ylabel2 = 'biomass (---), profit (___)';
            % Ylabel3 = 'heat (---), ventilation (___), CO2 (...)';
            Ylabel1 = 'TEMI, DDI, CI';
            Ylabel2 = 'biomass, profit';
            Ylabel3 = 'heating, ventilation, CO2';
            Ylabel4 = 'climate data';
            Legend1 = ['TEMI  '; 'DDI   '; 'CI/100'];
            Legend2 = ['biomass/100'; 'profit     '];
            Legend3 = ['heating '; 'ventil. '; 'CO2*10  '];
            Legend4 = ['TEMB    ';'TEMG    ';'TEMA    ';'FA      ';'CA/10   ';'IGLOB/10';'U*10    '];
            Legend5 = ['TEMB    ';'TEMG    ';'TEMA    ';'FA      ';'IGLOB/10'];
         end

      % Plot of Temperatur innen TEMI, Dampfdruck innen DDI and Kohlendioxid innen CI
         SubPlotX = 4; SubPlotY = 1;
         subplot(SubPlotX,SubPlotY,1), plot(th, x(IxPlot,2), '--', th, x(IxPlot,1), '-', th, x(IxPlot,3)/100, ':');
         title(Title1);
         xlabel(Xlabelall); ylabel(Ylabel1);
         legend(Legend1, 2);
         set(gca,'XLim', XLimTime);
      
      % Plot of Biomasse BIOM and Gewinn GEWINN
         subplot(SubPlotX,SubPlotY,2), plot(th, x(IxPlot,4)/100, '--', th, x(IxPlot,5), '-');
         title(Title2);
         xlabel(Xlabelall); ylabel(Ylabel2);
         legend(Legend2, 2);
         set(gca,'XLim', XLimTime);
      
      % Plot of Controls
         subplot(SubPlotX,SubPlotY,3), plot(th, ControlTable(IxPlot,1), '--', th, ControlTable(IxPlot,2), '-', th, ControlTable(IxPlot,3)*10, ':');
         title(Title3);
         xlabel(Xlabelall); ylabel(Ylabel3);
         legend(Legend3, 2);
         set(gca,'XLim', XLimTime);
         
      % Plot of Klima
         % Get data of Klima and Plant
         if isempty(KlimaPlant),
            if isempty(DataKlimaPlant), [KLIMA PLANT] = klidata4(t); KlimaPlant = [KLIMA PLANT];
            else KlimaPlant = table1(DataKlimaPlant, t); end
            % Compute temperature of greenhouse cover
            for iklima = 1:length(t),
               KlimaPlant(iklima, 2) = calctemg(x(iklima,2), KlimaPlant(iklima, 3), KlimaPlant(iklima,6), t(iklima));
            end
         end
         KLIMA = KlimaPlant(:,1:7); PLANT = KlimaPlant(:,8:10);
         subplot(SubPlotX,SubPlotY,4);
         if length(IxPlot) > 100, IxPlotK = IxPlot(1:4:length(IxPlot)); end
         thK = th(IxPlotK);
         % HandleLines = plot(thK, KLIMA(IxPlotK, 1),     '-', thK, KLIMA(IxPlotK, 2),     '--', ...
         %                    thK, KLIMA(IxPlotK, 3),     ':', thK, KLIMA(IxPlotK, 4),     '-.', ...
         %                    thK, KLIMA(IxPlotK, 5)./10, '-', thK, KLIMA(IxPlotK, 6)./10, '--', ...
         %                    thK, KLIMA(IxPlotK, 7).*10, ':');
         HandleLines = plot(thK, KLIMA(IxPlotK, 1),     '-', thK, KLIMA(IxPlotK, 2),     '--', ...
                            thK, KLIMA(IxPlotK, 3),     ':', thK, KLIMA(IxPlotK, 4),     '-.', ...
                            thK, KLIMA(IxPlotK, 6)./10, '--' );
         compplot('set_linestyle', HandleLines);
         title(Title4);
         xlabel(Xlabelall); ylabel(Ylabel4);
         legend(Legend5, 2);  % Place legend
         set(gca,'XLim', XLimTime);

         drawnow;
         iinput = iinput +1;

      end
      
   else
      % plot of Dampfdruck innen DDI
         subplot(3,3,1), plot(th, x(:,[1]), '-');
         title('DDI');
         xlabel('time'); ylabel('Dampfdruck innen');

      % plot of Temperatur innen TEMPI
         subplot(3,3,2), plot(th, x(:,[2]), '-');
         title(['TEMPI']);
         xlabel('time'); ylabel('Temperatur innen');

      % plot of Kohlendioxid innen CI
         subplot(3,3,3), plot(th, x(:,[3]), '-');
         title(['CI']);
         xlabel('time'); ylabel('Kohlendioxid innen');

      % plot of Biomasse BIOM
         subplot(3,3,4); plot(th, x(:,[4]), '-');
         title('BIOM');
         xlabel('time'); ylabel('Biomasse');

      % plot of Gewinn GEWINN
         subplot(3,3,5); plot(th, x(:,[5]), '-');
         title(['GEWINN']);
         xlabel('time'); ylabel('Gewinn');

      % plot of Feuchte innen FI
         subplot(3,3,6); plot(th, feuchtei(x(:,[1]),x(:,[2])), '-');
         title(['FI']);
         xlabel('time'); ylabel('Feuchte innen');
      
      % plot of Heizung Q
         subplot(3,3,7); plot(th, ControlTable(:,1)','-');
         title(['Q']);
         xlabel('time'); ylabel('Heizung');

      % plot of Lueftung LR
         subplot(3,3,8); plot(th, ControlTable(:,2)','-');
         title(['LR']);
         xlabel('time'); ylabel('Lueftung');

      % plot of Kohlendioxidzugabe W
         subplot(3,3,9); plot(th, ControlTable(:,3)','-');
         title(['W']);
         xlabel('time'); ylabel('Kohlendioxid');
   
   end
   
   drawnow;


% End of function

