% SCRipt for running multiple GReenHouSe climate optimizations 10
%
% This script performs evolutionary optimizations of the 
% greenhouse system over long time periods.
% For optimization the long time periods are divided into
% smaller parts. This script performs evolutionary optimizations
% for every small time period. The results (states) of one small
% time period are used as starting point for the next small time
% period. Additionally, long result files are written for quick 
% access to computed results.
% Thus, arbitrary long time periods can be optimized using even
% moderate computers.
%
% Syntax:  scrgrh10
%
% Input parameter:
%    keine
%
% Output parameter:
%    keine
%
% See also: objgrhs4, plotgrh3, recvgrh3, initgrh3, simgrhs4

% Author:   Hartmut Pohlheim
% History:  13.03.97    file created


   global GLOBAL_INITFUN;
   global GLOBAL_STATEPLOTFUN;
   global GLOBAL_FILERESULTS;
   global GLOBAL_FILEMAT;

   clear goptions;

   goptions( 1,1) = 0;         % Output
   goptions( 5,1) = 0;         % selection function
   goptions( 7,[1:3]) = [0, 2, 0];         % recombination function
   goptions(14,1) = 500;        % MAXGEN
   goptions(20,1) = 40;        % NIND
   goptions(21,1) = 3;         % SUBPOP
   goptions(22,1) = 0.50;      % Generation gap
   goptions(24,[1:3]) = [0.1, 0.01, 0.001];    % Mutation range (Radius)
   goptions(25,[1:3]) = [10, 10, 10];      % Mutation precision
   goptions(26,1) = 2;        % SP
   % goptions(33,1) = 20;       % Migration interval
   goptions(41,1) = 1;        % SAVE2FILE
   goptions(42,1) = 0;        % INITFUNCTION
   goptions(43,1) = 0;        % STATEPLOTFUNCTION
   goptions(44,1) = 5;        % GLOBAL_FILEMAT
   % goptions(51,1) = 10;       % Termination algorithm
   % goptions(53,1) = 1.4;      % Maximal time (in minutes)
   % goptions(61,1) = 5;        % PlotTime (Standardplot erstellen)
   % goptions(62,1) = 11000100;        % PlotMask
   % goptions(63,1) = 11000300;        % PlotStyle
   
   objfun = 'objgrhs4';

   % ResultPath = 'results/';
   ResultPath = '/home/intelligent/pohlheim/grenhaus/results/';
   FileNameAll = [ResultPath 'mp713122'];
   GLOBAL_INITFUN = 'initgrh4';
   GLOBAL_STATEPLOTFUN = 'plotgrh4';
   GLOBAL_FILERESULTS = [FileNameAll '.res'];
   GLOBAL_FILEMAT = FileNameAll;


   FileSave = [FileNameAll '.sim'];   % Name des Files, in dem die Simulationsergebnisse gespeichert werden
   PrintStep = 1/4;           % Gibt an, wie oft pro Stunde die Simulationsergebnisse ausgegeben werden
   % PRICES = [];
   PRICES = [3, 1, 5e-5];     % Preis fr Gemse: 3 DM/kg; Kohlendioxid: 1 DM/kg; Heizl: 0.00005 = 13.9 DM/GJ
   PlantModel = 3;            % New paprika model: 3

   % Beginn der Simulation in Stunden (gerechnet vom 1.1.)
   HoursperMonth = compgrhs('hours_per_month');
   TSMonth = 7; TSDay = 1; TSHour = 3;
   TStartOffset = sum(HoursperMonth(1:TSMonth-1))+(TSDay-1)*24+TSHour;
   TSimGesamt = 9*1;            % Dauer der gesamten Simulation in Stunden
   TSimTeil   = 9;               % Dauer einer Teilsimulation in Stunden
   
   % Do optimization over whole simulation period
   for xruning = [1],
      Beginn =  0;
      Ende = ceil((TSimGesamt-TSimTeil)/TSimTeil);
      for ilauf = Beginn:Ende,
         TS = (TStartOffset + ilauf * TSimTeil) * 3600;
         TE = TS + TSimTeil * 3600 - 1;
         bounds = feval(objfun, [], 1, TS, TE);
         VLB = bounds(1,:); VUB = bounds(2,:);
         % disp(sprintf('%d: %10g   %10g', ilauf, TS/3600/24, TE/3600/24));
         
         if ilauf == Beginn, xinit = []; PrintHeader = 1;
         else xinit = xinitnext; PrintHeader = 0; end

         DataKlimaPlant = compgrhs('lookup_klimaplant', TS, TE);
         [xnew] = tbxmpea(objfun, goptions, VLB, VUB, PlantModel, TS, TE, DataKlimaPlant, xinit, PRICES);
         xinitnext = recvgrh3(objfun, xnew(1,:), PlantModel, TS, TE, DataKlimaPlant, xinit, PRICES, FileSave, PrintStep, PrintHeader);
      end
   end
   

% End of script
